
"""
The worl's most awesome bonjour monde module
"""
import sys

__version__ = '0.0.3'


def bonjour(name='Monde'):
    """
    Return a greeting for a given name.
    """
    return 'Bonjour, {}'.format(name)


def main():
    """
    Reads input from args passed into the script and \
    prints the output to stout.
    """
    args = sys.argv[1:]
    name = ' '.join(args)
    if name:
        print(bonjour(name))
    else:
        print(bonjour())


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
from setuptools import setup
from bonjour import __version__

with open('readme.rst') as f:
    readme = f.read()
with open('CHANGES.rst') as f:
    changes = f.read()

setup(
    # The name of the package
    name='bonjour',
    # The number of the version for the package
    version=__version__,
    # A short description of the package
    description='A module / utility to say hello to you in French.',
    # description description (displayed on PyPI's page for the package)
    long_description=readme + '\n\n' + changes,
    # The maintainer
    author='Emilie',
    # Thei email
    author_email='emilie@wegotpop.com',
    # The package's website
    url='https://github.com/Em774/bonjour_monde',
    # The Python modules to include
    py_modules=['bonjour', ],
    # The license type
    license='MIT',
    # Helpful classifications / metadata
    classifiers=[
        'Development Status :: 4 - Beta',
    ],
    # Links the "bonjour" command with a function to call
    entry_points={
        'console_scripts': ['bonjour=bonjour:main'],
    }
)
